@@ -1,5 +1,6 @@
 
 --- Fetch back-end for retrieving sources from Subversion.
+--module("luarocks.fetch.svn", package.seeall)
 local svn = {}
 
 local unpack = unpack or table.unpack
@@ -16,7 +17,7 @@ local util = require("luarocks.util")
 -- the fetched source tarball and the temporary directory created to
 -- store it; or nil and an error message.
 function svn.get_sources(rockspec, extract, dest_dir)
-   assert(rockspec:type() == "rockspec")
+   assert(type(rockspec) == "table")
    assert(type(dest_dir) == "string" or not dest_dir)
 
    local svn_cmd = rockspec.variables.SVN
