@@ -1,14 +1,14 @@
 local site_config = {}
 site_config.LUAROCKS_PREFIX=[[/usr]]
-site_config.LUA_INCDIR=[[/usr/include]]
+site_config.LUA_INCDIR=[[/usr/include/lua5.1]]
 site_config.LUA_LIBDIR=[[/usr/lib]]
 site_config.LUA_BINDIR=[[/usr/bin]]
-site_config.LUA_INTERPRETER=[[lua5.3]]
+site_config.LUA_INTERPRETER=[[lua5.1]]
 site_config.LUAROCKS_SYSCONFDIR=[[/etc/luarocks]]
 site_config.LUAROCKS_ROCKS_TREE=[[/usr]]
-site_config.LUAROCKS_ROCKS_SUBDIR=[[/lib/luarocks/rocks-5.3]]
+site_config.LUAROCKS_ROCKS_SUBDIR=[[/lib/luarocks/rocks-5.1]]
 site_config.LUAROCKS_UNAME_S=[[Linux]]
-site_config.LUAROCKS_UNAME_M=[[armv5tel]]
+site_config.LUAROCKS_UNAME_M=[[armv6l]]
 site_config.LUAROCKS_DOWNLOADER=[[curl]]
 site_config.LUAROCKS_MD5CHECKER=[[md5sum]]
 return site_config
